//
//  ONSLGameManager.m
//  ONSLauncher
//
//  Created by tmkk on Wed Mar 08 2006.
//  Copyright (c) 2006 tmkk. All rights reserved.
//

#import "ONSLGameManager.h"
#import "ONSLGameInfo.h"
#import "ONSLController.h"
#import "ONSLFontManager.h"
#import "NSFontAdditions.h"

@implementation ONSLGameManager

- (id)init
{
	[super init];
	delegate = nil;
	gameInfoArr = [[NSMutableArray alloc] init];
	return self;
}

- (id)initWithDelegate:(id)del
{
	[self init];
	delegate = [del retain];
	return self;
}

- (void)dealloc
{
	[gameInfoArr release];
	if(delegate) [delegate release];
	[super dealloc];
}

- (int)numberOfGames
{
	return [gameInfoArr count];
}

- (void)addGameInfo:(id)gameInfo
{
	[gameInfoArr addObject:gameInfo];
}

- (id)gameInfoAtIndex:(int)idx
{
	return [gameInfoArr objectAtIndex:idx];
}

- (void)removeGameInfoAtIndex:(int)idx
{
	[gameInfoArr removeObjectAtIndex:idx];
}

- (void)terminateAllGames
{
	int i;
	for(i=0;i<[gameInfoArr count];i++) {
		[[gameInfoArr objectAtIndex:i] terminate];
	}
}
- (BOOL)terminateOK
{
	int i;
	for(i=0;i<[gameInfoArr count];i++) {
		if([[gameInfoArr objectAtIndex:i] isPlaying]) return NO;
	}
	return YES;
}

- (id)saveGameList
{
	int i;
	NSMutableArray *arr = [[[NSMutableArray alloc] init] autorelease];
	NSMutableDictionary *dic;
	for(i=0;i<[gameInfoArr count];i++) {
		id game = [gameInfoArr objectAtIndex:i];
		dic = [[NSMutableDictionary alloc] init];
		[dic setObject:[game title] forKey:@"Title"];
		[dic setObject:[game path] forKey:@"Path"];
		if([game fontName]) [dic setObject:[game fontName] forKey:@"FontName"];
		[dic setObject:[[game font] fontName] forKey:@"FontNamePS"];
		[dic setObject:[game imagePath] forKey:@"ImagePath"];
		[dic setObject:[game otherArgs] forKey:@"OtherArgs"];
		[dic setObject:[NSNumber numberWithBool:[game fullscreenMode]] forKey:@"FullscreenMode"];
		[dic setObject:[NSNumber numberWithBool:[game varEditMode]] forKey:@"VarEditMode"];
		[dic setObject:[NSNumber numberWithBool:[game wheelAdvanceMode]] forKey:@"WheelAdvanceMode"];
		[dic setObject:[NSNumber numberWithBool:[game drawOutlinedFont]] forKey:@"DrawOutlinedFont"];
		[arr addObject:dic];
		[dic release];
	}
	return arr;
}

- (void)loadGameList:(id)list
{
	int i;
	for(i=0;i<[list count];i++) {
		ONSLGameInfo *game = [[ONSLGameInfo alloc] initWithDelegate:delegate];
		id dic = [list objectAtIndex:i];
		[game setTitle:[dic objectForKey:@"Title"]];
		[game setPath:[dic objectForKey:@"Path"]];
		if([dic objectForKey:@"FontNamePS"]) {
			[game setFont:[NSFont fontWithName:[dic objectForKey:@"FontNamePS"] size:18]];
		}
		else if([dic objectForKey:@"FontName"]) {
			//[game setFontName:[dic objectForKey:@"FontName"]];
			NSFont *font = [NSFont fontWithPath:[[delegate fontManager] fontNamed:[dic objectForKey:@"FontName"]] size:18];
			[game setFont:font];
		}
		[game setImagePath:[dic objectForKey:@"ImagePath"]];
		[game setOtherArgs:[dic objectForKey:@"OtherArgs"]];
		[game setFullscreenMode:[[dic objectForKey:@"FullscreenMode"] boolValue]];
		[game setVarEditMode:[[dic objectForKey:@"VarEditMode"] boolValue]];
		if([dic objectForKey:@"WheelAdvanceMode"])
			[game setWheelAdvanceMode:[[dic objectForKey:@"WheelAdvanceMode"] boolValue]];
		if([dic objectForKey:@"DrawOutlinedFont"])
			[game setDrawOutlinedFont:[[dic objectForKey:@"DrawOutlinedFont"] boolValue]];
		[gameInfoArr addObject:game];
		[game release];
	}
}

- (NSMutableArray*)gameInfoArray
{
	return gameInfoArr;
}

@end
