//
//  ONSLUpdateManager.m
//  ONSLauncher
//
//  Created by tmkk on 06/04/18.
//  Copyright 2006 tmkk. All rights reserved.
//

#import "ONSLUpdateManager.h"
#import "ONSLController.h"

@implementation ONSLUpdateManager

- (id)init
{
	[super init];
	conn = nil;
	delegate = nil;
	fileName = nil;
	return self;
}

- (id)initWithDelegate:(id)del
{
	[self init];
	delegate = [del retain];
	return self;
}

- (void)dealloc
{
	if(delegate) [delegate release];
	if(fileName) [fileName release];
	[super dealloc];
}

- (void)beginDownload:(NSURL *)url
{
	NSURLRequest *req = [NSURLRequest requestWithURL:url];
	conn = [[NSURLConnection alloc] initWithRequest:req delegate:self];
}

- (void)cancelDownload
{
	if(conn) {
		[conn cancel];
		[conn release];
	}
	if(fileName) {
		const char *cmd = [[NSString stringWithFormat:@"rm %@",[[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:fileName]] UTF8String];
		system(cmd);
		[fileName release];
	}
	conn = nil;
	fileName = nil;
}

-(void)connection:(NSURLConnection *)connection didReceiveResponse:(NSURLResponse *)response
{
	if([(NSHTTPURLResponse *)response statusCode] >= 400) {
		[conn cancel];
		[delegate updateFailed];
		[conn release];
		conn = nil;
		return;
	}
	[delegate setProgressLimit:[response expectedContentLength]];
	fileName = [[response suggestedFilename] retain];
	[[NSFileManager defaultManager] createFileAtPath:[[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:fileName] contents:nil attributes:nil];
}

- (void)connection:(NSURLConnection *)connection didFailWithError:(NSError *)error
{
	[delegate updateFailed];
	[conn release];
	if(fileName) [fileName release];
	conn = nil;
	fileName = nil;
}

- (void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data
{
	//NSLog([[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:fileName]);
	NSFileHandle *handle = [NSFileHandle fileHandleForWritingAtPath:[[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:fileName]];
	[handle seekToEndOfFile];
	[handle writeData:data];
	[handle closeFile];
	[delegate loadDataLength:[data length]];
}

-(void)connectionDidFinishLoading:(NSURLConnection *)connection
{
    NSFileManager *mgr = [NSFileManager defaultManager];
    char *tar = "/usr/bin/tar";
    if([mgr fileExistsAtPath:@"/usr/bin/gnutar"]) tar = "/usr/bin/gnutar";
	const char *cmd = [[NSString stringWithFormat:@"%s xvjf %@ -C %@",tar,[[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:fileName],[[NSBundle mainBundle] resourcePath]] UTF8String];
	system(cmd);
	cmd = [[NSString stringWithFormat:@"rm %@",[[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:fileName]] UTF8String];
	system(cmd);
	[delegate updateFinished];
	[conn release];
	[fileName release];
	conn = nil;
	fileName = nil;
}

@end
